@@ -35,76 +35,70 @@ isTRUE( expect_true(2 == 1 + 1) )
 
 
 ###################################################
-### code chunk number 5: using_tinytest.Rnw:149-151
+### code chunk number 5: using_tinytest.Rnw:150-152
 ###################################################
 expect_error(lbs2kg(-3), pattern="nonnegative")
 expect_error(lbs2kg(-3), pattern="foo")
 
 
 ###################################################
-### code chunk number 6: using_tinytest.Rnw:165-166
+### code chunk number 6: using_tinytest.Rnw:166-167
 ###################################################
 expect_false( 1 + 1 == 2 )
 
 
 ###################################################
-### code chunk number 7: using_tinytest.Rnw:188-189
+### code chunk number 7: using_tinytest.Rnw:196-197
 ###################################################
 print(expect_equal(1+1, 3), type="short")
 
 
 ###################################################
-### code chunk number 8: using_tinytest.Rnw:196-197 (eval = FALSE)
+### code chunk number 8: eval
 ###################################################
-## ?print.tinytests
+run_test_file("test_addOne.R", verbose=0)
 
 
 ###################################################
-### code chunk number 9: eval
+### code chunk number 9: using_tinytest.Rnw:243-245
 ###################################################
-run_test_file("test_addOne.R", verbose=FALSE)
-
-
-###################################################
-### code chunk number 10: using_tinytest.Rnw:237-239
-###################################################
-test_results <- run_test_file("test_addOne.R", verbose=FALSE)
+test_results <- run_test_file("test_addOne.R", verbose=0)
 print(test_results, passes=TRUE)
 
 
 ###################################################
-### code chunk number 11: using_tinytest.Rnw:242-243 (eval = FALSE)
+### code chunk number 10: using_tinytest.Rnw:248-249 (eval = FALSE)
 ###################################################
 ## options(tt.pr.passes=TRUE)
 
 
 ###################################################
-### code chunk number 12: using_tinytest.Rnw:249-250 (eval = FALSE)
+### code chunk number 11: using_tinytest.Rnw:255-256 (eval = FALSE)
 ###################################################
 ## run_test_dir("/path/to/your/test/directory")
 
 
 ###################################################
-### code chunk number 13: using_tinytest.Rnw:257-259
+### code chunk number 12: using_tinytest.Rnw:263-265
 ###################################################
 out <- run_test_dir(system.file("tinytest", package="tinytest")
-       , verbose=FALSE)
+       , verbose=0)
 
 
 ###################################################
-### code chunk number 14: using_tinytest.Rnw:263-264
+### code chunk number 13: using_tinytest.Rnw:269-270
 ###################################################
 head(as.data.frame(out), 3)
 
 
 ###################################################
-### code chunk number 15: using_tinytest.Rnw:270-271
+### code chunk number 14: using_tinytest.Rnw:276-277
 ###################################################
 summary(out)
 
 
 ###################################################
-### code chunk number 16: using_tinytest.Rnw:281-284 (eval = FALSE)
+### code chunk number 15: using_tinytest.Rnw:287-290 (eval = FALSE)
 ###################################################
 ## if ( expect_equal(1 + 1, 2) ){
 ##     expect_true( 2 > 0)
@@ -112,7 +106,7 @@ summary(out)
 
 
 ###################################################
-### code chunk number 17: using_tinytest.Rnw:294-297
+### code chunk number 16: using_tinytest.Rnw:300-303
 ###################################################
 if ( ignore(expect_equal)(1+1, 2) ){
   expect_true(2>0)
@@ -120,7 +114,15 @@ if ( ignore(expect_equal)(1+1, 2) ){
 
 
 ###################################################
-### code chunk number 18: using_tinytest.Rnw:318-324 (eval = FALSE)
+### code chunk number 17: using_tinytest.Rnw:311-314
+###################################################
+if ( Sys.info()[['sysname']] == "Windows"){
+  exit_file("Cannot test this on Windows")
+}
+
+
+###################################################
+### code chunk number 18: using_tinytest.Rnw:341-347 (eval = FALSE)
 ###################################################
 ## run_test_dir("/path/to/my/testdir"
 ##            , remove_side_effects = FALSE)
@@ -131,44 +133,62 @@ if ( ignore(expect_equal)(1+1, 2) ){
 
 
 ###################################################
-### code chunk number 19: using_tinytest.Rnw:331-332 (eval = FALSE)
+### code chunk number 19: using_tinytest.Rnw:354-355 (eval = FALSE)
 ###################################################
 ## options(tt.collate="C")
 
 
 ###################################################
-### code chunk number 20: using_tinytest.Rnw:357-358 (eval = FALSE)
+### code chunk number 20: using_tinytest.Rnw:371-372 (eval = FALSE)
+###################################################
+## test_package("pkg", side_effects=TRUE)
+
+
+###################################################
+### code chunk number 21: using_tinytest.Rnw:376-377 (eval = FALSE)
+###################################################
+## test_package("pkg", side_effects=list(pwd=FALSE))
+
+
+###################################################
+### code chunk number 22: using_tinytest.Rnw:405-406
+###################################################
+run_test_file("test_se.R", verbose=1)
+
+
+###################################################
+### code chunk number 23: using_tinytest.Rnw:452-453 (eval = FALSE)
 ###################################################
 ## setup_tinytest("/path/to/your/package")
 
 
 ###################################################
-### code chunk number 21: using_tinytest.Rnw:371-372 (eval = FALSE)
+### code chunk number 24: using_tinytest.Rnw:466-467 (eval = FALSE)
 ###################################################
 ## test_all("/path/to/your/package")
 
 
 ###################################################
-### code chunk number 22: using_tinytest.Rnw:383-384 (eval = FALSE)
+### code chunk number 25: using_tinytest.Rnw:478-479 (eval = FALSE)
 ###################################################
 ##   build_install_test("/path/to/your/package")
 
 
 ###################################################
-### code chunk number 23: using_tinytest.Rnw:416-418 (eval = FALSE)
+### code chunk number 26: using_tinytest.Rnw:511-513 (eval = FALSE)
 ###################################################
 ## dat <- read.csv("women.csv")
 ## expect_equal(dat, women)
 
 
 ###################################################
-### code chunk number 24: using_tinytest.Rnw:430-431
+### code chunk number 27: using_tinytest.Rnw:525-526
 ###################################################
 options(prompt="  ", continue="  ")
 
 
 ###################################################
-### code chunk number 25: using_tinytest.Rnw:433-438 (eval = FALSE)
+### code chunk number 28: using_tinytest.Rnw:528-533 (eval = FALSE)
 ###################################################
 ## # contents of pkgdir/tests/tinytest.R
 ## if ( requireNamespace("tinytest", quietly=TRUE) ){
@@ -178,38 +198,66 @@ options(prompt="  ", continue="  ")
 
 
 ###################################################
-### code chunk number 26: using_tinytest.Rnw:443-444
+### code chunk number 29: using_tinytest.Rnw:538-539
 ###################################################
 home <- identical( Sys.getenv("HONEYIMHOME"), "TRUE" )
 
 
 ###################################################
-### code chunk number 27: using_tinytest.Rnw:448-449 (eval = FALSE)
+### code chunk number 30: using_tinytest.Rnw:543-544 (eval = FALSE)
 ###################################################
 ## home <- length(unclass(packageVersion("PKGNAME"))[[1]]) == 4
 
 
 ###################################################
-### code chunk number 28: using_tinytest.Rnw:453-454
+### code chunk number 31: using_tinytest.Rnw:548-549
 ###################################################
 options(prompt="R> ", continue="   ")
 
 
 ###################################################
-### code chunk number 29: using_tinytest.Rnw:461-463
+### code chunk number 32: using_tinytest.Rnw:556-558
 ###################################################
-run_test_file("test_hehe.R", verbose=FALSE)
-run_test_file("test_hehe.R", verbose=FALSE, at_home=FALSE)
+run_test_file("test_hehe.R", verbose=0)
+run_test_file("test_hehe.R", verbose=0, at_home=FALSE)
 
 
 ###################################################
-### code chunk number 30: using_tinytest.Rnw:503-504 (eval = FALSE)
+### code chunk number 33: using_tinytest.Rnw:582-583 (eval = FALSE)
 ###################################################
 ## tinytest::test_package("hehe")
 
 
 ###################################################
-### code chunk number 31: using_tinytest.Rnw:522-531
+### code chunk number 34: using_tinytest.Rnw:627-628 (eval = FALSE)
+###################################################
+## build_install_test("/path/to/your/package", ncpu=2)
+
+
+###################################################
+### code chunk number 35: using_tinytest.Rnw:639-640 (eval = FALSE)
+###################################################
+## test_package("PACKAGENAME", ncpu=2)
+
+
+###################################################
+### code chunk number 36: using_tinytest.Rnw:662-665 (eval = FALSE)
+###################################################
+## cl <- parallel::makeCluster(4, outfile="")
+## parallel::clusterCall(cl, source, "R/myfunctions.R")
+## run_test_dir("inst/tinytest", cluster=cl)
+
+
+###################################################
+### code chunk number 37: using_tinytest.Rnw:672-675 (eval = FALSE)
+###################################################
+## parallel::clusterCall(cl, source, "R/myfunctions.R")
+## test_all(cluster=cl)
+## stopCluster(cl)
+
+
+###################################################
+### code chunk number 38: using_tinytest.Rnw:709-718
 ###################################################
 # exported, user-visible function
 inch2cm <- function(x){
@@ -223,7 +271,7 @@ conversion_factor <- function(unit){
 
 
 ###################################################
-### code chunk number 32: using_tinytest.Rnw:574-582
+### code chunk number 39: using_tinytest.Rnw:761-769
 ###################################################
 pound2kg <- function(x){
   stopifnot( is.numeric(x) )
@@ -236,7 +284,7 @@ pound2kg <- function(x){
 
 
 ###################################################
-### code chunk number 33: using_tinytest.Rnw:601-607 (eval = FALSE)
+### code chunk number 40: using_tinytest.Rnw:788-794 (eval = FALSE)
 ###################################################
 ##     expect_equal(pound2kg(1), 1/2.2046  )
 ##     # test for expected warning, store output
@@ -246,3 +294,31 @@ pound2kg <- function(x){
 ##     expect_error(pound2kg("foo"))
 
 
+###################################################
+### code chunk number 41: using_tinytest.Rnw:839-845
+###################################################
+bad_function <- function(file){
+  oldwd <- getwd()
+  setwd(dirname(file))
+  source(basename(file))
+  setwd(oldwd)
+}
+
+
+###################################################
+### code chunk number 42: using_tinytest.Rnw:852-852
+###################################################
+
+
+
+###################################################
+### code chunk number 43: using_tinytest.Rnw:853-859
+###################################################
+good_function <- function(file){
+  oldwd <- getwd()
+  on.exit(setwd(oldwd))
+  setwd(dirname(file))
+  source(basename(file))
+}
+
+
