@@ -29,7 +29,13 @@ expect_equivalent(2,c(x=2))
 expect_true(ignore(expect_equivalent)(2,c(x=2)))
 expect_false(ignore(expect_equivalent)(2,c(x=3)))
 
+# check NULL
+expect_true(ignore(expect_null)(NULL))
+expect_false(ignore(expect_null)(1))
 
+
+
+# reading from file
 dat <- read.csv("women.csv")
 expect_equal(women, dat)
 
